grib2io.tables.section4_discipline3 API documentation

# grib2io.tables.section4_discipline3

View Source

      1table_4_2_3_0  = {
      2'0':['Scaled Radiance','Numeric','SRAD'],
      3'1':['Scaled Albedo','Numeric','SALBEDO'],
      4'2':['Scaled Brightness Temperature','Numeric','SBTMP'],
      5'3':['Scaled Precipitable Water','Numeric','SPWAT'],
      6'4':['Scaled Lifted Index','Numeric','SLFTI'],
      7'5':['Scaled Cloud Top Pressure','Numeric','SCTPRES'],
      8'6':['Scaled Skin Temperature','Numeric','SSTMP'],
      9'7':['Cloud Mask','See Table 4.217','CLOUDM'],
     10'8':['Pixel scene type','See Table 4.218','PIXST'],
     11'9':['Fire Detection Indicator','See Table 4.223','FIREDI'],
     12'10-191':['Reserved','unknown','unknown'],
     13'192-254':['Reserved for Local Use','unknown','unknown'],
     14'255':['Missing','unknown','unknown'],
     15}
     16table_4_2_3_1  = {
     17'0':['Estimated Precipitation','kg m-2','ESTP'],
     18'1':['Instantaneous Rain Rate','kg m-2 s-1','IRRATE'],
     19'2':['Cloud Top Height','m','CTOPH'],
     20'3':['Cloud Top Height Quality Indicator','Code table 4.219','CTOPHQI'],
     21'4':['Estimated u-Component of Wind','m s-1','ESTUGRD'],
     22'5':['Estimated v-Component of Wind','m s-1','ESTVGRD'],
     23'6':['Number Of Pixels Used','Numeric','NPIXU'],
     24'7':['Solar Zenith Angle','°','SOLZA'],
     25'8':['Relative Azimuth Angle','°','RAZA'],
     26'9':['Reflectance in 0.6 Micron Channel','%','RFL06'],
     27'10':['Reflectance in 0.8 Micron Channel','%','RFL08'],
     28'11':['Reflectance in 1.6 Micron Channel','%','RFL16'],
     29'12':['Reflectance in 3.9 Micron Channel','%','RFL39'],
     30'13':['Atmospheric Divergence','s-1','ATMDIV'],
     31'14':['Cloudy Brightness Temperature','K','CBTMP'],
     32'15':['Clear Sky Brightness Temperature','K','CSBTMP'],
     33'16':['Cloudy Radiance (with respect to wave number)','W m-1 sr-1','CLDRAD'],
     34'17':['Clear Sky Radiance (with respect to wave number)','W m-1 sr-1','CSKYRAD'],
     35'18':['Reserved','unknown','unknown'],
     36'19':['Wind Speed','m s-1','WINDS'],
     37'20':['Aerosol Optical Thickness at 0.635 µm','unknown','AOT06'],
     38'21':['Aerosol Optical Thickness at 0.810 µm','unknown','AOT08'],
     39'22':['Aerosol Optical Thickness at 1.640 µm','unknown','AOT16'],
     40'23':['Angstrom Coefficient','unknown','ANGCOE'],
     41'24-26':['Reserved','unknown','unknown'],
     42'27':['Bidirectional Reflecance Factor','Numeric','BRFLF'],
     43'28':['Brightness Temperature','K','SPBRT'],
     44'29':['Scaled Radiance','Numeric','SCRAD'],
     45'30-97':['Reserved','unknown','unknown'],
     46'98':['Correlation coefficient between MPE rain rates for the co-located IR data and the microwave data rain rates','Numeric','CCMPEMRR'],
     47'99':['Standard deviation between MPE rain rates for the co-located IR data and the microwave data rain rates','Numeric','SDMPEMRR'],
     48'100-191':['Reserved','unknown','unknown'],
     49'192-254':['Reserved for Local Use','unknown','unknown'],
     50'192':['Scatterometer Estimated U Wind Component','m s-1','USCT'],
     51'193':['Scatterometer Estimated V Wind Component','m s-1','VSCT'],
     52'194':['Scatterometer Wind Quality','unknown','SWQI'],
     53'255':['Missing','unknown','unknown'],
     54}
     55table_4_2_3_2  = {
     56'0':['Clear Sky Probability','%','CSKPROB'],
     57'1':['Cloud Top Temperature','K','CTOPTMP'],
     58'2':['Cloud Top Pressure','Pa','CTOPRES'],
     59'3':['Cloud Type','See Table 4.218','CLDTYPE'],
     60'4':['Cloud Phase','See Table 4.218','CLDPHAS'],
     61'5':['Cloud Optical Depth','Numeric','CLDODEP'],
     62'6':['Cloud Particle Effective Radius','m','CLDPER'],
     63'7':['Cloud Liquid Water Path','kg m-2','CLDLWP'],
     64'8':['Cloud Ice Water Path','kg m-2','CLDIWP'],
     65'9':['Cloud Albedo','Numeric','CLDALB'],
     66'10':['Cloud Emissivity','Numeric','CLDEMISS'],
     67'11':['Effective Absorption Optical Depth Ratio','Numeric','EAODR'],
     68'12-29':['Reserved','unknown','unknown'],
     69'30':['Measurement cost','Numeric','MEACST'],
     70'41-191':['Reserved','unknown','unknown'],
     71'192-254':['Reserved for Local Use','unknown','unknown'],
     72'255':['Missing','unknown','unknown'],
     73}
     74table_4_2_3_3  = {
     75'0':['Probability of Encountering Marginal Visual Flight Rules Conditions','%','PBMVFRC'],
     76'1':['Probability of Encountering Low Instrument Flight Rules Conditions','%','PBLIFRC'],
     77'2':['Probability of Encountering Instrument Flight Rules Conditions','%','PBINFRC'],
     78'3-191':['Reserved','unknown','unknown'],
     79'192-254':['Reserved for Local Use','unknown','unknown'],
     80'255':['Missing','unknown','unknown'],
     81}
     82table_4_2_3_4  = {
     83'0':['Volcanic Ash Probability','%','VOLAPROB'],
     84'1':['Volcanic Ash Cloud Top Temperature','K','VOLACDTT'],
     85'2':['Volcanic Ash Cloud Top Pressure','Pa','VOLACDTP'],
     86'3':['Volcanic Ash Cloud Top Height','m','VOLACDTH'],
     87'4':['Volcanic Ash Cloud Emissity','Numeric','VOLACDEM'],
     88'5':['Volcanic Ash Effective Absorption Depth Ratio','Numeric','VOLAEADR'],
     89'6':['Volcanic Ash Cloud Optical Depth','Numeric','VOLACDOD'],
     90'7':['Volcanic Ash Column Density','kg m-2','VOLACDEN'],
     91'8':['Volcanic Ash Particle Effective Radius','m','VOLAPER'],
     92'9-191':['Reserved','unknown','unknown'],
     93'192-254':['Reserved for Local Use','unknown','unknown'],
     94'255':['Missing','unknown','unknown'],
     95}
     96table_4_2_3_5  = {
     97'0':['Interface Sea-Surface Temperature','K','ISSTMP'],
     98'1':['Skin Sea-Surface Temperature','K','SKSSTMP'],
     99'2':['Sub-Skin Sea-Surface Temperature','K','SSKSSTMP'],
    100'3':['Foundation Sea-Surface Temperature','K','FDNSSTMP'],
    101'4':['Estimated bias between Sea-Surface Temperature and Standard','K','EBSSTSTD'],
    102'5':['Estimated bias Standard Deviation between Sea-Surface Temperature and Standard','K','EBSDSSTS'],
    103'6-191':['Reserved','unknown','unknown'],
    104'192-254':['Reserved for Local Use','unknown','unknown'],
    105'255':['Missing','unknown','unknown'],
    106}
    107table_4_2_3_6  = {
    108'0':['Global Solar Irradiance','W m-2','GSOLIRR'],
    109'1':['Global Solar Exposure','J m-2','GSOLEXP'],
    110'2':['Direct Solar Irradiance','W m-2','DIRSOLIR'],
    111'3':['Direct Solar Exposure','J m-2','DIRSOLEX'],
    112'4':['Diffuse Solar Irradiance','W m-2','DIFSOLIR'],
    113'5':['Diffuse Solar Exposure','J m-2','DIFSOLEX'],
    114'6-191':['Reserved','unknown','unknown'],
    115'192-254':['Reserved for Local Use','unknown','unknown'],
    116'255':['Missing','unknown','unknown'],
    117}
    118table_4_2_3_192  = {
    119'0':['Simulated Brightness Temperature for GOES 12, Channel 2','K','SBT122'],
    120'1':['Simulated Brightness Temperature for GOES 12, Channel 3','K','SBT123'],
    121'2':['Simulated Brightness Temperature for GOES 12, Channel 4','K','SBT124'],
    122'3':['Simulated Brightness Temperature for GOES 12, Channel 6','K','SBT126'],
    123'4':['Simulated Brightness Counts for GOES 12, Channel 3','Byte','SBC123'],
    124'5':['Simulated Brightness Counts for GOES 12, Channel 4','Byte','SBC124'],
    125'6':['Simulated Brightness Temperature for GOES 11, Channel 2','K','SBT112'],
    126'7':['Simulated Brightness Temperature for GOES 11, Channel 3','K','SBT113'],
    127'8':['Simulated Brightness Temperature for GOES 11, Channel 4','K','SBT114'],
    128'9':['Simulated Brightness Temperature for GOES 11, Channel 5','K','SBT115'],
    129'10':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 9','K','AMSRE9'],
    130'11':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 10','K','AMSRE10'],
    131'12':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 11','K','AMSRE11'],
    132'13':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 12','K','AMSRE12'],
    133'14':['Simulated Reflectance Factor for ABI GOES-16, Band-1','unknown','SRFA161'],
    134'15':['Simulated Reflectance Factor for ABI GOES-16, Band-2','unknown','SRFA162'],
    135'16':['Simulated Reflectance Factor for ABI GOES-16, Band-3','unknown','SRFA163'],
    136'17':['Simulated Reflectance Factor for ABI GOES-16, Band-4','unknown','SRFA164'],
    137'18':['Simulated Reflectance Factor for ABI GOES-16, Band-5','unknown','SRFA165'],
    138'19':['Simulated Reflectance Factor for ABI GOES-16, Band-6','unknown','SRFA166'],
    139'20':['Simulated Brightness Temperature for ABI GOES-16, Band-7','K','SBTA167'],
    140'21':['Simulated Brightness Temperature for ABI GOES-16, Band-8','K','SBTA168'],
    141'22':['Simulated Brightness Temperature for ABI GOES-16, Band-9','K','SBTA169'],
    142'23':['Simulated Brightness Temperature for ABI GOES-16, Band-10','K','SBTA1610'],
    143'24':['Simulated Brightness Temperature for ABI GOES-16, Band-11','K','SBTA1611'],
    144'25':['Simulated Brightness Temperature for ABI GOES-16, Band-12','K','SBTA1612'],
    145'26':['Simulated Brightness Temperature for ABI GOES-16, Band-13','K','SBTA1613'],
    146'27':['Simulated Brightness Temperature for ABI GOES-16, Band-14','K','SBTA1614'],
    147'28':['Simulated Brightness Temperature for ABI GOES-16, Band-15','K','SBTA1615'],
    148'29':['Simulated Brightness Temperature for ABI GOES-16, Band-16','K','SBTA1616'],
    149'30':['Simulated Reflectance Factor for ABI GOES-17, Band-1','unknown','SRFA171'],
    150'31':['Simulated Reflectance Factor for ABI GOES-17, Band-2','unknown','SRFA172'],
    151'32':['Simulated Reflectance Factor for ABI GOES-17, Band-3','unknown','SRFA173'],
    152'33':['Simulated Reflectance Factor for ABI GOES-17, Band-4','unknown','SRFA174'],
    153'34':['Simulated Reflectance Factor for ABI GOES-17, Band-5','unknown','SRFA175'],
    154'35':['Simulated Reflectance Factor for ABI GOES-17, Band-6','unknown','SRFA176'],
    155'36':['Simulated Brightness Temperature for ABI GOES-17, Band-7','K','SBTA177'],
    156'37':['Simulated Brightness Temperature for ABI GOES-17, Band-8','K','SBTA178'],
    157'38':['Simulated Brightness Temperature for ABI GOES-17, Band-9','K','SBTA179'],
    158'39':['Simulated Brightness Temperature for ABI GOES-17, Band-10','K','SBTA1710'],
    159'40':['Simulated Brightness Temperature for ABI GOES-17, Band-11','K','SBTA1711'],
    160'41':['Simulated Brightness Temperature for ABI GOES-17, Band-12','K','SBTA1712'],
    161'42':['Simulated Brightness Temperature for ABI GOES-17, Band-13','K','SBTA1713'],
    162'43':['Simulated Brightness Temperature for ABI GOES-17, Band-14','K','SBTA1714'],
    163'44':['Simulated Brightness Temperature for ABI GOES-17, Band-15','K','SBTA1715'],
    164'45':['Simulated Brightness Temperature for ABI GOES-17, Band-16','K','SBTA1716'],
    165'46':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-1','unknown','SRFAGR1'],
    166'47':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-2','unknown','SRFAGR2'],
    167'48':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-3','unknown','SRFAGR3'],
    168'49':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-4','unknown','SRFAGR4'],
    169'50':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-5','unknown','SRFAGR5'],
    170'51':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-6','unknown','SRFAGR6'],
    171'52':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-7','unknown','SBTAGR7'],
    172'53':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-8','unknown','SBTAGR8'],
    173'54':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-9','unknown','SBTAGR9'],
    174'55':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-10','unknown','SBTAGR10'],
    175'56':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-11','unknown','SBTAGR11'],
    176'57':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-12','unknown','SBTAGR12'],
    177'58':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-13','unknown','SBTAGR13'],
    178'59':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-14','unknown','SBTAGR14'],
    179'60':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-15','unknown','SBTAGR15'],
    180'61':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-16','unknown','SBTAGR16'],
    181'62':['Simulated Brightness Temperature for SSMIS-F17, Channel 15','K','SSMS1715'],
    182'63':['Simulated Brightness Temperature for SSMIS-F17, Channel 16','K','SSMS1716'],
    183'64':['Simulated Brightness Temperature for SSMIS-F17, Channel 17','K','SSMS1717'],
    184'65':['Simulated Brightness Temperature for SSMIS-F17, Channel 18','K','SSMS1718'],
    185'66':['Simulated Brightness Temperature for Himawari-8, Band-7','K','SBTAHI7'],
    186'67':['Simulated Brightness Temperature for Himawari-8, Band-8','K','SBTAHI8'],
    187'68':['Simulated Brightness Temperature for Himawari-8, Band-9','K','SBTAHI9'],
    188'69':['Simulated Brightness Temperature for Himawari-8, Band-10','K','SBTAHI10'],
    189'70':['Simulated Brightness Temperature for Himawari-8, Band-11','K','SBTAHI11'],
    190'71':['Simulated Brightness Temperature for Himawari-8, Band-12','K','SBTAHI12'],
    191'72':['Simulated Brightness Temperature for Himawari-8, Band-13','K','SBTAHI13'],
    192'73':['Simulated Brightness Temperature for Himawari-8, Band-14','K','SBTAHI14'],
    193'74':['Simulated Brightness Temperature for Himawari-8, Band-15','K','SBTAHI15'],
    194'75':['Simulated Brightness Temperature for Himawari-8, Band-16','K','SBTAHI16'],
    195'76':['Simulated Brightness Temperature for ABI GOES-18, Band-7','K','SBTA187'],
    196'77':['Simulated Brightness Temperature for ABI GOES-18, Band-8','K','SBTA188'],
    197'78':['Simulated Brightness Temperature for ABI GOES-18, Band-9','K','SBTA189'],
    198'79':['Simulated Brightness Temperature for ABI GOES-18, Band-10','K','SBTA1810'],
    199'80':['Simulated Brightness Temperature for ABI GOES-18, Band-11','K','SBTA1811'],
    200'81':['Simulated Brightness Temperature for ABI GOES-18, Band-12','K','SBTA1812'],
    201'82':['Simulated Brightness Temperature for ABI GOES-18, Band-13','K','SBTA1813'],
    202'83':['Simulated Brightness Temperature for ABI GOES-18, Band-14','K','SBTA1814'],
    203'84':['Simulated Brightness Temperature for ABI GOES-18, Band-15','K','SBTA1815'],
    204'85':['Simulated Brightness Temperature for ABI GOES-18, Band-16','K','SBTA1816'],
    205'86-191':['Reserved','unknown','unknown'],
    206'192-254':['Reserved for Local Use','unknown','unknown'],
    207'255':['Missing','unknown','unknown'],
    208}